Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3505)

Unified Diff: chrome/browser/policy/cloud/user_cloud_policy_store_base.h

Issue 19733003: Implement cloud policy invalidations using the invalidation service framework. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 7 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/policy/cloud/user_cloud_policy_store_base.h
diff --git a/chrome/browser/policy/cloud/user_cloud_policy_store_base.h b/chrome/browser/policy/cloud/user_cloud_policy_store_base.h
index 514983a8d1098783db1174ef217938d6bb77da7b..6cedbc458e698440020303f1acbfcc3aba0db24a 100644
--- a/chrome/browser/policy/cloud/user_cloud_policy_store_base.h
+++ b/chrome/browser/policy/cloud/user_cloud_policy_store_base.h
@@ -27,10 +27,12 @@ class UserCloudPolicyStoreBase : public CloudPolicyStore {
scoped_ptr<UserCloudPolicyValidator> CreateValidator(
scoped_ptr<enterprise_management::PolicyFetchResponse> policy);
// Sets |policy_data| and |payload| as the active policy.
void InstallPolicy(
scoped_ptr<enterprise_management::PolicyData> policy_data,
- scoped_ptr<enterprise_management::CloudPolicySettings> payload);
+ scoped_ptr<enterprise_management::CloudPolicySettings> payload,
+ uint32 policy_hash_value);
private:
DISALLOW_COPY_AND_ASSIGN(UserCloudPolicyStoreBase);
@@ -27,10 +27,12 @@ class UserCloudPolicyStoreBase : public CloudPolicyStore {
scoped_ptr<UserCloudPolicyValidator> CreateValidator(
scoped_ptr<enterprise_management::PolicyFetchResponse> policy);
- // Sets |policy_data| and |payload| as the active policy.
+ // Sets |policy_data| and |payload| with hash |policy_hash_value| as the
+ // active policy.
void InstallPolicy(
scoped_ptr<enterprise_management::PolicyData> policy_data,

Powered by Google App Engine
This is Rietveld 408576698